@@ -5,9 +5,9 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include <QtTest>
-#include <ksharedconfig.h>
+#include <QTest>
 #include <kconfiggroup.h>
+#include <ksharedconfig.h>
 
 class KSharedConfigTest : public QObject
 {
@@ -18,6 +18,7 @@ private Q_SLOTS:
     void testReadWrite();
     void testReadWriteSync();
     void testQrcFile();
+
 private:
     QString m_path;
 };
@@ -26,8 +27,8 @@ void KSharedConfigTest::initTestCase()
 {
     QStandardPaths::setTestModeEnabled(true);
 
-    m_path = QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation)
-            + QLatin1Char('/') + QCoreApplication::applicationName() + QStringLiteral("rc");
+    m_path =
+        QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation) + QLatin1Char('/') + QCoreApplication::applicationName() + QStringLiteral("rc");
     QFile::remove(m_path);
 }
 
