@@ -92,7 +92,7 @@ public:
     KConfigGroup(const KConfigGroup &);
     KConfigGroup &operator=(const KConfigGroup &);
 
-    ~KConfigGroup();
+    ~KConfigGroup() override;
 
     /**
      * Whether the group is valid.
@@ -113,7 +113,7 @@ public:
     QString name() const;
 
     /**
-     * Check whether the containing KConfig object acutally contains a
+     * Check whether the containing KConfig object actually contains a
      * group with this name.
      */
     bool exists() const;
@@ -194,6 +194,14 @@ public:
      */
     void reparent(KConfigBase *parent, WriteConfigFlags pFlags = Normal);
 
+    /**
+     * Moves the key-value pairs from one config group to the other.
+     * In case the entries do not exist the key is ignored.
+     *
+     * @since 5.88
+     */
+    void moveValuesTo(const QList<const char *> &keys, KConfigGroup &other, WriteConfigFlags pFlags = Normal);
+
     /**
      * Returns the group that this group belongs to
      *
@@ -721,7 +729,9 @@ private:
      * @return @p value converted to QVariant, or @p aDefault if @p value is invalid or cannot be converted.
      */
     static QVariant convertToQVariant(const char *pKey, const QByteArray &value, const QVariant &aDefault);
+    // exported for usage by KServices' KService & KServiceAction
     friend class KServicePrivate; // XXX yeah, ugly^5
+    friend class KServiceAction;
 };
 
 #define KCONFIGGROUP_ENUMERATOR_ERROR(ENUM) "The Qt MetaObject system does not seem to know about \"" ENUM "\" please use Q_ENUM or Q_FLAG to register it."
@@ -746,7 +756,7 @@ private:
         const QByteArray M_data = readEntry(key, QByteArray(M_enum.valueToKey(def)));                                                                          \
         return static_cast<Class::Enum>(M_enum.keyToValue(M_data.constData()));                                                                                \
     }                                                                                                                                                          \
-    inline Class::Enum Q_DECL_DEPRECATED readEntry(const KConfigGroup &group, const char *key, const Class::Enum &def)                                         \
+    inline Class::Enum KCONFIGCORE_DECL_DEPRECATED readEntry(const KConfigGroup &group, const char *key, const Class::Enum &def)                               \
     {                                                                                                                                                          \
         return group.readEntry(key, def);                                                                                                                      \
     }                                                                                                                                                          \
@@ -760,10 +770,10 @@ private:
         const QMetaEnum M_enum = M_obj->enumerator(M_index);                                                                                                   \
         writeEntry(key, QByteArray(M_enum.valueToKey(value)), flags);                                                                                          \
     }                                                                                                                                                          \
-    inline void Q_DECL_DEPRECATED writeEntry(KConfigGroup &group,                                                                                              \
-                                             const char *key,                                                                                                  \
-                                             const Class::Enum &value,                                                                                         \
-                                             KConfigBase::WriteConfigFlags flags = KConfigBase::Normal)                                                        \
+    inline void KCONFIGCORE_DECL_DEPRECATED writeEntry(KConfigGroup &group,                                                                                    \
+                                                       const char *key,                                                                                        \
+                                                       const Class::Enum &value,                                                                               \
+                                                       KConfigBase::WriteConfigFlags flags = KConfigBase::Normal)                                              \
     {                                                                                                                                                          \
         group.writeEntry(key, value, flags);                                                                                                                   \
     }
@@ -784,7 +794,7 @@ private:
         const QByteArray M_data = readEntry(key, QByteArray(M_enum.valueToKeys(def)));                                                                         \
         return static_cast<Class::Flags>(M_enum.keysToValue(M_data.constData()));                                                                              \
     }                                                                                                                                                          \
-    inline Class::Flags Q_DECL_DEPRECATED readEntry(const KConfigGroup &group, const char *key, const Class::Flags &def)                                       \
+    inline Class::Flags KCONFIGCORE_DECL_DEPRECATED readEntry(const KConfigGroup &group, const char *key, const Class::Flags &def)                             \
     {                                                                                                                                                          \
         return group.readEntry(key, def);                                                                                                                      \
     }                                                                                                                                                          \
@@ -798,10 +808,10 @@ private:
         const QMetaEnum M_enum = M_obj->enumerator(M_index);                                                                                                   \
         writeEntry(key, QByteArray(M_enum.valueToKeys(value)), flags);                                                                                         \
     }                                                                                                                                                          \
-    inline void Q_DECL_DEPRECATED writeEntry(KConfigGroup &group,                                                                                              \
-                                             const char *key,                                                                                                  \
-                                             const Class::Flags &value,                                                                                        \
-                                             KConfigBase::WriteConfigFlags flags = KConfigBase::Normal)                                                        \
+    inline void KCONFIGCORE_DECL_DEPRECATED writeEntry(KConfigGroup &group,                                                                                    \
+                                                       const char *key,                                                                                        \
+                                                       const Class::Flags &value,                                                                              \
+                                                       KConfigBase::WriteConfigFlags flags = KConfigBase::Normal)                                              \
     {                                                                                                                                                          \
         group.writeEntry(key, value, flags);                                                                                                                   \
     }
